@@ -37,7 +37,7 @@ class UploaderTest(unittest.TestCase):
 
     @patch.object(Uploader, '_post')
     def test_flush(self, mocked_post):
-        signal = signals_pb2.MLSignal()
+        signal = signals_pb2.WorkerSignal()
         graphsignal._agent.uploader().upload_signal(signal)
         graphsignal._agent.uploader().flush()
 
@@ -47,7 +47,7 @@ class UploaderTest(unittest.TestCase):
     @patch.object(Uploader, '_post',
                   return_value=signals_pb2.UploadResponse().SerializeToString())
     def test_flush_in_thread(self, mocked_post):
-        signal = signals_pb2.MLSignal()
+        signal = signals_pb2.WorkerSignal()
         graphsignal._agent.uploader().upload_signal(signal)
         graphsignal._agent.uploader().flush_in_thread()
 
@@ -60,7 +60,7 @@ class UploaderTest(unittest.TestCase):
             raise URLError("Ex1")
         mocked_post.side_effect = side_effect
 
-        signal = signals_pb2.MLSignal()
+        signal = signals_pb2.WorkerSignal()
         graphsignal._agent.uploader().upload_signal(signal)
         graphsignal._agent.uploader().upload_signal(signal)
         graphsignal._agent.uploader().flush()
@@ -75,10 +75,10 @@ class UploaderTest(unittest.TestCase):
             signals_pb2.UploadResponse().SerializeToString())
         server.start()
 
-        signal = signals_pb2.MLSignal()
-        signal.model_name = 'm1'
+        signal = signals_pb2.WorkerSignal()
+        signal.endpoint_name = 'ep1'
         upload_request = signals_pb2.UploadRequest()
-        upload_request.ml_signals.append(signal)
+        upload_request.worker_signals.append(signal)
         upload_request.upload_ms = 123
         graphsignal._agent.uploader()._post(
             'signals', upload_request.SerializeToString())
@@ -86,7 +86,7 @@ class UploaderTest(unittest.TestCase):
         received_upload_request = signals_pb2.UploadRequest()
         received_upload_request.ParseFromString(server.get_request_data())
         self.assertEqual(
-            received_upload_request.ml_signals[0].model_name, 'm1')
+            received_upload_request.worker_signals[0].endpoint_name, 'ep1')
         self.assertEqual(received_upload_request.upload_ms, 123)
 
         server.join()
@@ -99,10 +99,10 @@ class UploaderTest(unittest.TestCase):
             signals_pb2.UploadResponse().SerializeToString())
         server.start()
 
-        signal = signals_pb2.MLSignal()
-        signal.model_name = 'm1'
+        signal = signals_pb2.WorkerSignal()
+        signal.endpoint_name = 'ep1'
         upload_request = signals_pb2.UploadRequest()
-        upload_request.ml_signals.append(signal)
+        upload_request.worker_signals.append(signal)
         upload_request.upload_ms = 123
         graphsignal._agent.uploader()._post(
             'signals', upload_request.SerializeToString())
@@ -110,7 +110,7 @@ class UploaderTest(unittest.TestCase):
         received_upload_request = signals_pb2.UploadRequest()
         received_upload_request.ParseFromString(server.get_request_data())
         self.assertEqual(
-            received_upload_request.ml_signals[0].model_name, 'm1')
+            received_upload_request.worker_signals[0].endpoint_name, 'ep1')
         self.assertEqual(received_upload_request.upload_ms, 123)
 
         server.join()
