@@ -6,7 +6,6 @@ import platform
 import time
 import re
 import multiprocessing
-import subprocess
 import socket
 try:
     import resource
@@ -14,7 +13,7 @@ except ImportError:
     pass
 
 import graphsignal
-from graphsignal.proto import profiles_pb2
+from graphsignal.proto import signals_pb2
 from graphsignal.proto_utils import parse_semver
 from graphsignal import version
 
@@ -32,7 +31,10 @@ MEM_FREE_REGEXP = re.compile(r'MemFree:\s+(\d+)\s+kB')
 
 
 class ProcessReader():
+    MIN_CPU_READ_INTERVAL_NS = 1 * 1e9
+
     def __init__(self):
+        self._start_ms = int(time.time() * 1e3)
         self._last_read_sec = None
         self._last_cpu_time_ns = None
 
@@ -42,39 +44,29 @@ class ProcessReader():
     def shutdown(self):
         pass
 
-    def start(self):
-        self.read(profiles_pb2.MLProfile())
-
-    def read(self, profile):
+    def read(self, signal):
         now = time.time()
         pid = str(os.getpid())
 
-        node_usage = profile.node_usage
-        process_usage = profile.process_usage
+        node_usage = signal.node_usage
+        process_usage = signal.process_usage
+        process_usage.start_ms = self._start_ms
 
         process_usage.process_id = pid
 
-        if OS_LINUX:
-            cpu_name = _read_cpu_name()
-            if cpu_name:
-                process_usage.cpu_name = cpu_name
-        elif OS_DARWIN:
-            cpu_name = _read_cpu_name_mac()
-            if cpu_name:
-                process_usage.cpu_name = cpu_name
-
         if not OS_WIN:
             cpu_time_ns = _read_cpu_time()
             if cpu_time_ns is not None:
                 if self._last_cpu_time_ns is not None:
-                    cpu_diff_ns = cpu_time_ns - self._last_cpu_time_ns
                     interval_ns = (now - self._last_read_sec) * 1e9
-                    cpu_usage = (cpu_diff_ns / interval_ns) * 100
-                    try:
-                        cpu_usage = cpu_usage / multiprocessing.cpu_count()
-                    except Exception:
-                        pass
-                    process_usage.cpu_usage_percent = cpu_usage
+                    if interval_ns > ProcessReader.MIN_CPU_READ_INTERVAL_NS:
+                        cpu_diff_ns = cpu_time_ns - self._last_cpu_time_ns
+                        cpu_usage = (cpu_diff_ns / interval_ns) * 100
+                        try:
+                            cpu_usage = cpu_usage / multiprocessing.cpu_count()
+                        except Exception:
+                            pass
+                        process_usage.cpu_usage_percent = cpu_usage
 
                 if (self._last_read_sec is None or now - self._last_read_sec > 0):
                     self._last_read_sec = now
@@ -118,44 +110,16 @@ class ProcessReader():
             logger.error('Error reading node information', exc_info=True)
 
         try:
-            process_usage.runtime = profiles_pb2.ProcessUsage.Runtime.PYTHON
+            process_usage.runtime = signals_pb2.ProcessUsage.Runtime.PYTHON
             process_usage.runtime_version.major = sys.version_info.major
             process_usage.runtime_version.minor = sys.version_info.minor
             process_usage.runtime_version.patch = sys.version_info.micro
             process_usage.runtime_impl = platform.python_implementation()
-            parse_semver(profile.profiler_info.version, version.__version__)
+            parse_semver(signal.agent_info.version, version.__version__)
         except BaseException:
             logger.error('Error reading process information', exc_info=True)
 
 
-def _read_cpu_name():
-    try:
-        result = subprocess.run(['lscpu'], stdout=subprocess.PIPE)
-        output = result.stdout.decode()
-    except Exception:
-        return None
-
-    match = CPU_NAME_REGEXP.search(output)
-    if match:
-        return match.group(1)
-
-    return None
-
-
-def _read_cpu_name_mac():
-    try:
-        result = subprocess.run(['sysctl', '-a'], stdout=subprocess.PIPE)
-        output = result.stdout.decode()
-    except Exception:
-        return None
-
-    match = CPU_NAME_MAC_REGEXP.search(output)
-    if match:
-        return match.group(1)
-
-    return None
-
-
 def _read_cpu_time():
     rusage = resource.getrusage(resource.RUSAGE_SELF)
     return int((rusage.ru_utime + rusage.ru_stime) * 1e9)  # ns
@@ -194,7 +158,7 @@ def _read_vm_size():
         f = open('/proc/{0}/status'.format(os.getpid()))
         output = f.read()
         f.close()
-    except Exception:
+    except BaseException:
         return None
 
     match = VM_SIZE_REGEXP.search(output)
@@ -208,7 +172,7 @@ def _read_mem_total():
         f = open('/proc/meminfo')
         output = f.read()
         f.close()
-    except Exception:
+    except BaseException:
         return None
 
     match = MEM_TOTAL_REGEXP.search(output)
@@ -222,7 +186,7 @@ def _read_mem_free():
         f = open('/proc/meminfo')
         output = f.read()
         f.close()
-    except Exception:
+    except BaseException:
         return None
 
     match = MEM_FREE_REGEXP.search(output)
